# Copyright (C) 2009 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Provide review message bodies for proposed merges to Launchapd itself."""

from bzrlib import commands, merge_directive


def shim(params):
    from body_callback import body_callback
    return body_callback(params)


def proposer_callback(hook_params):
    from body_callback import get_body
    return get_body(hook_params['tree'], hook_params['target_branch'],
                    hook_params['modified_files_callback'],
                    hook_params['old_body'])


if getattr(merge_directive.MergeDirective, 'hooks', None) is not None:
    merge_directive.MergeDirective.hooks.install_named_hook(
        'merge_request_body',
        shim, 'Generate a message body for Launchpad merge requests.'
    )
try:
    from bzrlib.plugins.launchpad import lp_propose
except ImportError:
    pass
else:
    lp_propose.Proposer.hooks.install_named_hook(
            'merge_proposal_body',
            proposer_callback,
            'Generate a message body for Launchpad merge requests.'
        )


commands.plugin_cmds.register_lazy(
    'cmd_qa_ready', [], 'bzrlib.plugins.lpreview_body.qa_ready')
